==> JacORB1_1-full.tar.gz: JacORB1_1/src/jacorb/idl/Definition.java <==
/*
 *        JacORB - a free Java ORB
 *
 *   Copyright (C) 1997-98  Gerald Brose.
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Library General Public
 *   License as published by the Free Software Foundation; either
 *   version 2 of the License, or (at your option) any later version.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Library General Public License for more details.
 *
 *   You should have received a copy of the GNU Library General Public
 *   License along with this library; if not, write to the Free
 *   Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

package jacorb.idl;

/**
 * @author Gerald Brose
 * @version $Id: Definition.java,v 1.6 1999/11/25 16:03:58 brose Exp $
 */

import java.util.Vector;
import java.util.Enumeration;
import java.io.*;


class Definition 
    extends IdlSymbol
{
    private Declaration declaration;

    public Definition(int num)
    {
	super(num);
	pack_name = "";	
    }

    public void setPackage( String s, boolean propagate_into_included )
    {
        s = parser.pack_replace(s);
		super.setPackage(s, propagate_into_included);
		declaration.setPackage(s, propagate_into_included);
    }

    public void setEnclosingSymbol( IdlSymbol s )
    {
	if( enclosing_symbol != null && enclosing_symbol != s )
	{
	    System.err.println("was " + enclosing_symbol.getClass().getName() + " now: " + s.getClass().getName());
	    throw new RuntimeException("Compiler Error: trying to reassign container for " + name );
	}
	enclosing_symbol = s;
	declaration.setEnclosingSymbol(s);
    }

    public Declaration get_declaration()
    {
	return declaration;
    }

    public void set_declaration( Declaration d )
    {
	declaration = d;
    }

    public void set_included(boolean i)
    {
	included = i;
	declaration.set_included(i);
    }

    public void print(PrintWriter ps)
    {
	declaration.print(ps);
    }	

    public void parse() 
	
    {
	declaration.parse();
    }
}

==> JacORB1_3_11-full.tar.gz: JacORB1_3_11/src/jacorb/idl/Definition.java <==
/*
 *        JacORB - a free Java ORB
 *
 *   Copyright (C) 1997-2000  Gerald Brose.
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Library General Public
 *   License as published by the Free Software Foundation; either
 *   version 2 of the License, or (at your option) any later version.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Library General Public License for more details.
 *
 *   You should have received a copy of the GNU Library General Public
 *   License along with this library; if not, write to the Free
 *   Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

package jacorb.idl;

/**
 * @author Gerald Brose
 * @version $Id: Definition.java,v 1.8 2000/12/18 08:58:23 brose Exp $
 */

import java.util.Vector;
import java.util.Enumeration;
import java.io.*;


class Definition 
    extends IdlSymbol
{
    private Declaration declaration;

    public Definition(int num)
    {
	super(num);
	pack_name = "";	
    }

    public void setPackage( String s)
    {
        s = parser.pack_replace(s);
		super.setPackage(s);
		declaration.setPackage(s);
    }

    public void setEnclosingSymbol( IdlSymbol s )
    {
	if( enclosing_symbol != null && enclosing_symbol != s )
	{
	    System.err.println("was " + enclosing_symbol.getClass().getName() + " now: " + s.getClass().getName());
	    throw new RuntimeException("Compiler Error: trying to reassign container for " + name );
	}
	enclosing_symbol = s;
	declaration.setEnclosingSymbol(s);
    }

    public Declaration get_declaration()
    {
	return declaration;
    }

    public void set_declaration( Declaration d )
    {
	declaration = d;
    }

    public void set_included(boolean i)
    {
	included = i;
	declaration.set_included(i);
    }

    public void print(PrintWriter ps)
    {
	declaration.print(ps);
    }	

    public void parse() 
	
    {
	declaration.parse();
    }
}
